@@ -25,6 +25,8 @@
 
 #include <KTp/error-dictionary.h>
 
+#include <Solid/Networking>
+
 ErrorHandler::ErrorHandler(const Tp::AccountManagerPtr& am, QObject* parent)
     : QObject(parent)
 {
@@ -62,7 +64,10 @@ void ErrorHandler::handleErrors(const Tp::ConnectionStatus status)
                 showMessageToUser(i18nc("%1 ist the account name", "Could not connect %1. Authentication failed (is your password correct?)", account->displayName()), ErrorHandler::SystemMessageError);
                 break;
             case Tp::ConnectionStatusReasonNetworkError:
-                showMessageToUser(i18nc("%1 ist the account name", "Could not connect %1. There was a network error, check your connection", account->displayName()), ErrorHandler::SystemMessageError);
+                //if connected to the network, and there was a network error - display it. Otherwise do nothing.
+                if (Solid::Networking::status() == Solid::Networking::Connected) {
+                    showMessageToUser(i18nc("%1 ist the account name", "Could not connect %1. There was a network error, check your connection", account->displayName()), ErrorHandler::SystemMessageError);
+                }
                 break;
             default:
                 showMessageToUser(i18nc("%1 ist the account name, %2 the error message", "There was a problem while trying to connect %1 - %2", account->displayName(), KTp::ErrorDictionary::displayVerboseErrorMessage(connectionError)), ErrorHandler::SystemMessageError);
