@@ -30,7 +30,7 @@ class TelepathyMPRIS : public TelepathyKDEDModulePlugin
     Q_OBJECT
 
 public:
-    TelepathyMPRIS(KTp::GlobalPresence *globalPresence, QObject *parent = 0);
+    explicit TelepathyMPRIS(KTp::GlobalPresence *globalPresence, QObject *parent = 0);
     virtual ~TelepathyMPRIS();
 
     QString pluginName() const;
@@ -49,6 +49,7 @@ Q_SIGNALS:
 private:
     QStringList m_knownPlayers;
     bool m_presenceActivated;
+    QString m_nowPlayingText;
 };
 
 #endif // TELEPATHY_MPRIS_H
